Package: geneplotter
Title: Graphics related functions for Bioconductor
Version: 1.90.0
Authors@R: c(
    person("Robert", "Gentleman", role = "aut"),
    person("Rohit", "Satyam", role = "ctb",
            comment = "Converted geneplotter vignette from Sweave to RMarkdown / HTML."),
    person("Bioconductor Package Maintainer", role = "cre",
            email = "maintainer@bioconductor.org"))
Description: Functions for plotting genomic data
Depends: R (>= 2.10), methods, Biobase, BiocGenerics, lattice, annotate
Imports: AnnotationDbi, graphics, grDevices, grid, RColorBrewer, stats,
        utils
Suggests: Rgraphviz, fibroEset, hgu95av2.db, hu6800.db, hgu133a.db,
        BiocStyle, knitr
VignetteBuilder: knitr
License: Artistic-2.0
biocViews: Visualization
LazyLoad: yes
git_url: https://git.bioconductor.org/packages/geneplotter
git_branch: RELEASE_3_23
git_last_commit: 5aeaf77
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:13:37 UTC; biocbuild
Author: Robert Gentleman [aut],
  Rohit Satyam [ctb] (Converted geneplotter vignette from Sweave to
    RMarkdown / HTML.),
  Bioconductor Package Maintainer [cre]
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
