Package: geneplotter
Title: Graphics related functions for Bioconductor
Version: 1.91.0
Authors@R: c(
    person("Robert", "Gentleman", role = "aut"),
    person("Rohit", "Satyam", role = "ctb",
            comment = "Converted geneplotter vignette from Sweave to RMarkdown / HTML."),
    person("Bioconductor Package Maintainer", role = "cre",
            email = "maintainer@bioconductor.org"))
Description: Functions for plotting genomic data
Depends: R (>= 2.10), methods, Biobase, BiocGenerics, lattice, annotate
Imports: AnnotationDbi, graphics, grDevices, grid, RColorBrewer, stats,
        utils
Suggests: Rgraphviz, fibroEset, hgu95av2.db, hu6800.db, hgu133a.db,
        BiocStyle, knitr
VignetteBuilder: knitr
License: Artistic-2.0
biocViews: Visualization
LazyLoad: yes
Config/pak/sysreqs: libpng-dev libxml2-dev libssl-dev zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:29:56 UTC
RemoteUrl: https://github.com/bioc/geneplotter
RemoteRef: HEAD
RemoteSha: 5175c4c91df1bf559ec28b959860d9fac97e4e33
NeedsCompilation: no
Packaged: 2026-05-30 08:20:26 UTC; root
Author: Robert Gentleman [aut],
  Rohit Satyam [ctb] (Converted geneplotter vignette from Sweave to
    RMarkdown / HTML.),
  Bioconductor Package Maintainer [cre]
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
Built: R 4.6.0; ; 2026-05-30 11:53:36 UTC; unix
