
IMCAEntrezLink = structure(list(ITGB = NA, ITGA = NA, ILK = structure("3611", .Names = "35365_at"), 
#
# computed 24 Sept 2007 using hgu95av2.db revmap(hgu95av2SYMBOL) from nodes(IMCAgraph),
# then looking up the probes in hgu95av2ENTREZID
#
    CAV = NA, SHC = NA, FYN = structure("2534", .Names = "2039_s_at"), 
    GRB2 = structure("2885", .Names = "1565_s_at"), SOS = NA, 
    "Ha-Ras" = NA, Raf = NA, MEK = NA, ERK = NA, MYLK = structure("4638", .Names = "32847_at"), 
    MYO = NA, ACTN = NA, VCL = structure("7414", .Names = "36601_at"), 
    TLN = NA, PXN = structure("5829", .Names = "38644_at"), ZYX = structure("7791", .Names = "36958_at"), 
    VASP = structure("7408", .Names = "39105_at"), SH3D5 = NA, 
    TNS = NA, CAPN = NA, CAPNS = NA, SRC = structure("6714", .Names = "1938_at"), 
    FAK = NA, BCAR1 = NA, CSK = structure("1445", .Names = "1768_s_at"), 
    CRK = structure("1398", .Names = "38219_at"), DOCK1 = structure("1793", .Names = "37638_at"), 
    GRF2 = NA, RAP1 = NA, JNK = NA, GIT2 = structure("9815", .Names = "36741_at"), 
    ARHGEF = NA, PAK = NA, p85 = NA, p110 = NA, "Phosphatidylinositol signaling system" = NA, 
    VAV = NA, PDPK1 = structure("5170", .Names = "32029_at"), 
    AKT = NA, RAC = NA, CDC42 = structure("998", .Names = "39736_at"), 
    RHO = structure("6010", .Names = "32875_at"), PI5K = NA, 
    ROCK = NA, "MYO-P" = NA, "cell maintenance" = NA, "cell motility" = NA, 
    "F-actin" = NA, "cell proliferation" = NA), .Names = c("ITGB", 
"ITGA", "ILK", "CAV", "SHC", "FYN", "GRB2", "SOS", "Ha-Ras", 
"Raf", "MEK", "ERK", "MYLK", "MYO", "ACTN", "VCL", "TLN", "PXN", 
"ZYX", "VASP", "SH3D5", "TNS", "CAPN", "CAPNS", "SRC", "FAK", 
"BCAR1", "CSK", "CRK", "DOCK1", "GRF2", "RAP1", "JNK", "GIT2", 
"ARHGEF", "PAK", "p85", "p110", "Phosphatidylinositol signaling system", 
"VAV", "PDPK1", "AKT", "RAC", "CDC42", "RHO", "PI5K", "ROCK", 
"MYO-P", "cell maintenance", "cell motility", "F-actin", "cell proliferation"
))

